@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2011 Red Hat, Inc.
+ * Copyright (C) 2011-2018 Red Hat, Inc.
  *
  * All rights reserved.
  *
@@ -23,15 +23,22 @@
 
 static void
 _file_logger(int32_t t,
-	     struct qb_log_callsite *cs, time_t timestamp, const char *msg)
+	     struct qb_log_callsite *cs, struct timespec *timestamp, const char *msg)
 {
-	char output_buffer[QB_LOG_MAX_LEN];
+	char buffer[QB_LOG_MAX_LEN];
+	char *output_buffer = buffer;
 	struct qb_log_target *target = qb_log_target_get(t);
 	FILE *f = qb_log_target_user_data_get(t);
 
 	if (f == NULL) {
 		return;
 	}
+	if (target->max_line_length > QB_LOG_MAX_LEN) {
+		output_buffer = malloc(target->max_line_length);
+		if (!output_buffer) {
+			return;
+		}
+	}
 	output_buffer[0] = '\0';
 
 	qb_log_target_format(t, cs, timestamp, msg, output_buffer);
@@ -42,6 +49,9 @@ _file_logger(int32_t t,
 	if (target->file_sync) {
 		QB_FILE_SYNC(fileno(f));
 	}
+	if (target->max_line_length > QB_LOG_MAX_LEN) {
+		free(output_buffer);
+	}
 }
 
 static void
@@ -50,20 +60,53 @@ _file_close(int32_t t)
 	FILE *f = qb_log_target_user_data_get(t);
 
 	if (f) {
-		fclose(f);
 		(void)qb_log_target_user_data_set(t, NULL);
+		fclose(f);
 	}
 }
 
+static int
+_do_file_reload(const char *filename, int32_t target)
+{
+	struct qb_log_target *t = qb_log_target_get(target);
+	FILE *oldfile = qb_log_target_user_data_get(target);
+	FILE *newfile;
+	int saved_errno;
+	int rc;
+
+	if (filename == NULL) {
+		filename = t->filename;
+	}
+	newfile = fopen(filename, "a+");
+	saved_errno = errno;
+
+	qb_log_thread_pause(t);
+
+	if (newfile) {
+		/* Only close oldfile if newfile open succeeds */
+		if (oldfile) {
+			fclose(oldfile);
+		}
+
+		if (filename != t->filename) {
+			(void)strlcpy(t->filename, filename, PATH_MAX);
+		}
+		(void)qb_log_target_user_data_set(target, newfile);
+		rc = 0;
+	}
+	else {
+		rc = -saved_errno;
+	}
+	qb_log_thread_resume(t);
+
+	return rc;
+}
+
+/* The version called from the logger object */
 static void
 _file_reload(int32_t target)
 {
-	struct qb_log_target *t = qb_log_target_get(target);
-
-	if (t->instance) {
-		fclose(t->instance);
-	}
-	t->instance = fopen(t->filename, "a+");
+	(void)_do_file_reload(NULL, target);
 }
 
 int32_t
@@ -114,3 +157,9 @@ qb_log_file_close(int32_t t)
 {
 	qb_log_custom_close(t);
 }
+
+int32_t
+qb_log_file_reopen(int32_t t, const char *filename)
+{
+	return _do_file_reload(filename, t);
+}
