@@ -68,7 +68,7 @@ _poll_entry_check_generate_(struct qb_poll_entry *pe)
 	for (i = 0; i < 200; i++) {
 		pe->check = random();
 
-		if (pe->check != 0 && pe->check != 0xffffffff) {
+		if (pe->check != 0 && pe->check != UINT32_MAX) {
 			break;
 		}
 	}
@@ -475,12 +475,8 @@ try_again:
 		res = write(pipe_fds[1], &sig, sizeof(int32_t));
 		if (res == -1 && errno == EAGAIN) {
 			goto try_again;
-		} else if (res != sizeof(int32_t)) {
-			qb_util_log(LOG_ERR,
-				    "failed to write signal to pipe [%d]", res);
 		}
 	}
-	qb_util_log(LOG_TRACE, "got real signal [%d] sent to pipe", sig);
 }
 
 static void
@@ -643,8 +639,6 @@ _adjust_sigactions_(struct qb_signal_source *s)
 		if (needed) {
 			sigaddset(&s->signal_superset, i);
 			sigaction(i, &sa, NULL);
-		} else {
-			(void)signal(i, SIG_DFL);
 		}
 	}
 }
@@ -725,6 +719,7 @@ qb_loop_signal_mod(qb_loop_t * lp,
 	sig->p = p;
 
 	if (sig->signal != the_sig) {
+		(void)signal(sig->signal, SIG_DFL);
 		sig->signal = the_sig;
 		_adjust_sigactions_(s);
 	}
@@ -775,6 +770,7 @@ qb_loop_signal_del(qb_loop_t * lp, qb_loop_signal_handle handle)
 	}
 
 	qb_list_del(&sig->item.list);
+	(void)signal(sig->signal, SIG_DFL);
 	free(sig);
 	_adjust_sigactions_(s);
 	return 0;
