@@ -31,14 +31,11 @@ size_t
 strlcpy(char *dest, const char * src, size_t maxlen)
 {
 	size_t	srclen = strlen(src);
-	size_t	len2cpy = QB_MIN(maxlen-1, srclen);
 
-	/* check maxlen separately as it could have underflowed from 0 above. */
 	if (maxlen) {
-		if (len2cpy > 0) {
-			strncpy(dest, src, len2cpy+1);
-		}
-		/* Always terminate, even if its empty */
+		size_t len2cpy = QB_MIN(maxlen-1, srclen);
+
+		memcpy(dest, src, len2cpy);
 		dest[len2cpy] = '\0';
 	}
 	return srclen;
