@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010 Red Hat, Inc.
+ * Copyright (C) 2010-2022 Red Hat, Inc.
  *
  * All rights reserved.
  *
@@ -123,6 +123,19 @@ qb_thread_lock_destroy(qb_thread_lock_t * tl)
 	return res;
 }
 
+/* If the "coarse" monotonic clock is available, it provides the time as of the
+ * last clock tick (typically at millisecond resolution), which should be
+ * sufficient for expected uses of libqb. This is faster since it avoids a
+ * context switch to the kernel.
+ */
+#ifdef HAVE_MONOTONIC_CLOCK
+# ifdef CLOCK_REALTIME_COARSE
+#  define QB_CLOCK_REALTIME CLOCK_REALTIME_COARSE
+# else
+#  define QB_CLOCK_REALTIME CLOCK_REALTIME
+# endif
+#endif
+
 void
 qb_timespec_add_ms(struct timespec *ts, int32_t ms)
 {
@@ -136,102 +149,86 @@ qb_timespec_add_ms(struct timespec *ts, int32_t ms)
 #endif /* S_SPLINT_S */
 }
 
-#ifdef HAVE_MONOTONIC_CLOCK
 uint64_t
 qb_util_nano_current_get(void)
 {
-	uint64_t nano_monotonic;
+#ifdef HAVE_MONOTONIC_CLOCK
 	struct timespec ts;
 
-	clock_gettime(CLOCK_MONOTONIC, &ts);
-	nano_monotonic =
-	    (ts.tv_sec * QB_TIME_NS_IN_SEC) + (uint64_t) ts.tv_nsec;
-	return (nano_monotonic);
+	if (clock_gettime(CLOCK_MONOTONIC, &ts) == 0) {
+		return (ts.tv_sec * QB_TIME_NS_IN_SEC) + (uint64_t) ts.tv_nsec;
+	}
+#endif
+	return qb_util_nano_from_epoch_get();
 }
 
 uint64_t
 qb_util_nano_from_epoch_get(void)
 {
-	uint64_t nano_monotonic;
+#ifdef HAVE_MONOTONIC_CLOCK
 	struct timespec ts;
-#ifdef CLOCK_REALTIME_COARSE
-	clock_gettime(CLOCK_REALTIME_COARSE, &ts);
-#else
-	clock_gettime(CLOCK_REALTIME, &ts);
+
+	if (clock_gettime(QB_CLOCK_REALTIME, &ts) == 0) {
+		return (ts.tv_sec * QB_TIME_NS_IN_SEC) + (uint64_t) ts.tv_nsec;
+	}
 #endif
-	nano_monotonic =
-	    (ts.tv_sec * QB_TIME_NS_IN_SEC) + (uint64_t) ts.tv_nsec;
-	return (nano_monotonic);
+
+#ifdef HAVE_GETTIMEOFDAY
+	{
+		struct timeval time_from_epoch;
+
+		if (gettimeofday(&time_from_epoch, NULL) == 0) {
+			return (time_from_epoch.tv_sec * QB_TIME_NS_IN_SEC) +
+				(time_from_epoch.tv_usec * QB_TIME_NS_IN_USEC);
+		}
+	}
+#endif
+
+	return time(NULL) * QB_TIME_NS_IN_SEC;
 }
 
 uint64_t
 qb_util_nano_monotonic_hz(void)
 {
-	uint64_t nano_monotonic_hz;
+#ifdef HAVE_MONOTONIC_CLOCK
 	struct timespec ts;
 
-#if HAVE_CLOCK_GETRES_MONOTONIC
-	clock_getres(CLOCK_MONOTONIC, &ts);
-#else
-	if (clock_getres(CLOCK_REALTIME, &ts) != 0)
-	    qb_util_perror(LOG_ERR,"CLOCK_REALTIME");
+	if ((clock_getres(CLOCK_MONOTONIC, &ts) == 0)
+		|| (clock_getres(CLOCK_REALTIME, &ts) == 0)) {
+		return QB_TIME_NS_IN_SEC / (ts.tv_sec * QB_TIME_NS_IN_SEC + ts.tv_nsec);
+	}
 #endif
 
-	nano_monotonic_hz =
-	    QB_TIME_NS_IN_SEC / ((ts.tv_sec * QB_TIME_NS_IN_SEC) + ts.tv_nsec);
-
-	return (nano_monotonic_hz);
-}
-
-void
-qb_util_timespec_from_epoch_get(struct timespec *ts)
-{
-#ifdef CLOCK_REALTIME_COARSE
-	clock_gettime(CLOCK_REALTIME_COARSE, ts);
-#else
-	clock_gettime(CLOCK_REALTIME, ts);
-#endif
-}
-
-#else
-uint64_t
-qb_util_nano_current_get(void)
-{
-	return qb_util_nano_from_epoch_get();
-}
-
-uint64_t
-qb_util_nano_monotonic_hz(void)
-{
 	return sysconf(_SC_CLK_TCK);
 }
 
 void
 qb_util_timespec_from_epoch_get(struct timespec *ts)
 {
-	struct timeval time_from_epoch;
-	gettimeofday(&time_from_epoch, 0);
+#ifdef HAVE_MONOTONIC_CLOCK
+	if (clock_gettime(QB_CLOCK_REALTIME, ts) == 0) {
+		return;
+	}
+#endif
 
+#ifdef HAVE_GETTIMEOFDAY
+	{
+		struct timeval time_from_epoch;
+
+		if (gettimeofday(&time_from_epoch, NULL) == 0) {
 #ifndef S_SPLINT_S
-	ts->tv_sec = time_from_epoch.tv_sec;
-	ts->tv_nsec = time_from_epoch.tv_usec * QB_TIME_NS_IN_USEC;
+			ts->tv_sec = time_from_epoch.tv_sec;
+			ts->tv_nsec = time_from_epoch.tv_usec * QB_TIME_NS_IN_USEC;
 #endif /* S_SPLINT_S */
+			return;
+		}
+	}
+#endif
+
+	ts->tv_sec = time(NULL);
+	ts->tv_nsec = 0;
 }
 
-uint64_t
-qb_util_nano_from_epoch_get(void)
-{
-	uint64_t nano_from_epoch;
-	struct timeval time_from_epoch;
-	gettimeofday(&time_from_epoch, 0);
-
-	nano_from_epoch = ((time_from_epoch.tv_sec * QB_TIME_NS_IN_SEC) +
-			   (time_from_epoch.tv_usec * QB_TIME_NS_IN_USEC));
-
-	return (nano_from_epoch);
-}
-#endif /* HAVE_MONOTONIC_CLOCK */
-
 struct qb_util_stopwatch {
 	uint64_t started;
 	uint64_t stopped;
